@@ -1,5 +1,5 @@
 package CGI::Kwiki::Style;
-$VERSION = '0.16';
+$VERSION = '0.17';
 use strict;
 use base 'CGI::Kwiki';
 
@@ -35,12 +35,20 @@ See http://www.perl.com/perl/misc/Artistic.html
 
 =cut
 
-__Blog__
-a         {text-decoration: none}
 __Display__
-a         {text-decoration: none}
+body      {background-color: #fff; color: #000;}
+
+a         {text-decoration: none;}
+a:link    {color: #d64;}
+a:visited {color: #864;}
+a:hover   {text-decoration: underline}
+a:active  {text-decoration: underline}
 a.empty   {color: gray}
 a.private {color: black}
+
+.error    {color: #f00;}
+
+textarea  {width: 100%;}
 __SlideShow__
 pre { font-family: courier, monospace; font-weight: bolder }
 li  { font-size: 20pt; padding-top: 10 }
